@@ -24,7 +24,7 @@ class CMSSatchmoProductPlugin(CMSPluginBase):
 		if not hasattr(instance.product, 'site') or instance.product.site == Site.objects.get_current():
 			site_url = ''
 		else:
-			site_url = '//%s' % instance.site.domain
+			site_url = '//%s' % instance.product.site.domain
 
 		context.update({
 			'site_url': site_url,
@@ -86,7 +86,7 @@ class CMSSatchmoCategoryPlugin(CMSPluginBase):
 		if not hasattr(instance.category, 'site') or instance.category.site == Site.objects.get_current():
 			site_url = ''
 		else:
-			site_url = '//%s' % instance.site.domain
+			site_url = '//%s' % instance.category.site.domain
 
 		category = Category.objects.get(id=instance.category_id)
 		slug_list = [cat.slug for cat in category.parents()]
